@@ -76,7 +76,7 @@ class ChessDaskCluster:
         return game_data
 
     def __init__(self):
-        config_file = os.path.join(os.path.dirname(os.path.realpath(__file__)), "config", "config.yaml")
+        config_file = os.path.join(os.getcwd(), "config", "config.yaml")
         if not os.path.isfile(config_file):
             raise FileNotFoundError(
                 errno.ENOENT, os.strerror(errno.ENOENT), config_file)
